aboutsummaryrefslogtreecommitdiff
path: root/src/wallet/feebumper.h
diff options
context:
space:
mode:
authorGregory Sanders <gsanders87@gmail.com>2019-03-06 16:30:00 -0500
committerGregory Sanders <gsanders87@gmail.com>2019-04-11 07:21:49 -0400
commit0ea47ba7b38cc4b2b9175347cb5cd48fcd08da48 (patch)
tree18a1212973191aca891ece3bcfd52da9b89f467a /src/wallet/feebumper.h
parentc536dfbcb00fb15963bf5d507b7017c241718bf6 (diff)
downloadbitcoin-0ea47ba7b38cc4b2b9175347cb5cd48fcd08da48.tar.xz
generalize bumpfee to add inputs when needed
Diffstat (limited to 'src/wallet/feebumper.h')
-rw-r--r--src/wallet/feebumper.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/wallet/feebumper.h b/src/wallet/feebumper.h
index a1eb5d0e0d..f9cbfc5f68 100644
--- a/src/wallet/feebumper.h
+++ b/src/wallet/feebumper.h
@@ -28,8 +28,8 @@ enum class Result
//! Return whether transaction can be bumped.
bool TransactionCanBeBumped(const CWallet* wallet, const uint256& txid);
-//! Create bumpfee transaction.
-Result CreateTransaction(const CWallet* wallet,
+//! Create bumpfee transaction based on total amount.
+Result CreateTotalBumpTransaction(const CWallet* wallet,
const uint256& txid,
const CCoinControl& coin_control,
CAmount total_fee,
@@ -38,6 +38,15 @@ Result CreateTransaction(const CWallet* wallet,
CAmount& new_fee,
CMutableTransaction& mtx);
+//! Create bumpfee transaction based on feerate estimates.
+Result CreateRateBumpTransaction(CWallet* wallet,
+ const uint256& txid,
+ const CCoinControl& coin_control,
+ std::vector<std::string>& errors,
+ CAmount& old_fee,
+ CAmount& new_fee,
+ CMutableTransaction& mtx);
+
//! Sign the new transaction,
//! @return false if the tx couldn't be found or if it was
//! impossible to create the signature(s)